/* This file was generated by syncqt. */
#ifndef QT_QTNETWORKAUTH_VERSION_H
#define QT_QTNETWORKAUTH_VERSION_H

#define QTNETWORKAUTH_VERSION_STR "5.15.17"

#define QTNETWORKAUTH_VERSION 0x050F11

#endif // QT_QTNETWORKAUTH_VERSION_H
